#!/usr/bin/env node
"use strict";

var path = _interopRequireWildcard(require("path"));

var _github = require("./../../lib/github");

var _travisCi = require("./../../lib/travis-ci");

var _git = require("./../../lib/git");

var _template = require("./../../lib/template");

var _templates = require("./../templates");

var _yarn = require("./../../lib/yarn");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

async function run() {
  const repoName = process.argv[2];
  const githubToken = process.env.GITHUB_TOKEN;
  const travisToken = process.env.TRAVIS_TOKEN;
  const npmToken = process.env.NPM_TOKEN;
  console.log('\n');

  if (!repoName || !githubToken || !travisToken || !npmToken) {
    console.log('Usage: GITHUB_TOKEN=? TRAVIS_TOKEN=? NPM_TOKEN=? yarn create user/repo');
    return;
  }

  const [, packageName] = repoName.split('/');
  console.log('Creating GitHub Repository');
  const githubApi = await (0, _github.authenticate)(githubToken);
  await (0, _github.createRepo)(githubApi, repoName);
  console.log('Enabling Travis CI');
  await (0, _travisCi.activate)(repoName, travisToken);
  console.log('Writing project files');
  const today = new Date();
  const authorName = await (0, _git.getConfig)('user.name');
  const authorEmail = await (0, _git.getConfig)('user.email');
  const projectDirectory = path.resolve(packageName);
  await (0, _template.writeTemplate)(projectDirectory, (0, _templates.readme)({
    repoName
  }));
  await (0, _template.writeTemplate)(projectDirectory, (0, _templates.license)({
    authorName,
    today
  }));
  await (0, _template.writeTemplate)(projectDirectory, (0, _templates.gitignore)({}));
  await (0, _template.writeTemplate)(projectDirectory, (0, _templates.packagejson)({
    repoName,
    authorName,
    authorEmail
  }));
  await (0, _template.writeTemplate)(projectDirectory, (0, _templates.npmignore)({}));
  await (0, _template.writeTemplate)(projectDirectory, (0, _templates.flowconfig)({
    repoName
  }));
  await (0, _template.writeTemplate)(projectDirectory, (0, _templates.travisyml)({
    encryptedGitHubToken: await (0, _travisCi.encrypt)(repoName, `GITHUB_TOKEN=${githubToken}`, travisToken),
    encryptedNpmToken: await (0, _travisCi.encrypt)(repoName, `NPM_TOKEN=${npmToken}`, travisToken)
  }));
  await (0, _template.writeTemplate)(projectDirectory, (0, _templates.main)({}));
  await (0, _template.writeTemplate)(projectDirectory, (0, _templates.test)({
    repoName
  }));
  console.log('Installing npm Packages');
  await (0, _yarn.addPackages)(projectDirectory, 'development', ['ava', 'build-esm', 'flow-bin', 'flow-typed', 'overdub', 'semantic-release', 'standard-esnext']);
  console.log('Committing Changes');
  await (0, _git.commitChanges)(projectDirectory, `feat(${packageName}): Bootstrap project`);
  console.log('Pushing Changes');
  await (0, _git.pushChanges)(projectDirectory, repoName, githubToken);
}

run();